==> robodoc_4.0.18.orig.tar.gz: robodoc-4.0.18/Source/util.h <==
#ifndef ROBODOC_UTIL_H
#define ROBODOC_UTIL_H

/* TODO all the functions that operate
 on headers should be in headers.h */

#include "headers.h"

void                RB_SetCurrentFile( char *filename );
char               *RB_GetCurrentFile(  );

char               *RB_FilePart( char * );
void                RB_Analyse_Defaults_File( void );

void                RB_Slow_Sort( void );
void                RB_Reverse_List( void );
void                RB_Insert_In_List( struct RB_header **,
                                       struct RB_header * );
void                RB_Remove_From_List( struct RB_header **,
                                         struct RB_header * );
struct RB_header   *RB_Alloc_Header( void );
void                RB_Free_Header( struct RB_header * );
int                 RB_WordLen( char * );
char               *RB_StrDup( char * );
char               *RB_CookStr( char * );
void                RB_Say( char *, ... );
void                RB_Panic( char *, ... );
int                 RB_Str_Case_Cmp( char *s, char *t );
void                RB_TimeStamp( FILE * f );
char               *RB_Skip_Whitespace( char *buf );
#if 0
int                 RB_Has_Remark_Marker( char *lline_buffer );
#endif

void               *RB_Calloc( size_t count, size_t size );
void               *RB_Malloc( size_t size );
void                RB_Free( void *p );
void                RB_FputcLatin1ToUtf8( FILE *fp, int c );
void                RB_CopyFile( char* sourceFileName, char* destinationFileName );
int                 RB_Match( char* target, char* wildcard_expression );


#endif /* ROBODOC_UTIL_H */

==> robodoc-4.99.6.tar.gz: robodoc-4.99.6/Source/util.h <==
#ifndef ROBODOC_UTIL_H
#define ROBODOC_UTIL_H

/* TODO all the functions that operate
 on headers should be in headers.h */

#include "headers.h"

typedef int (*TCompare)( void*, void* );


void                RB_SetCurrentFile( char *filename );
char               *RB_GetCurrentFile(  );

char               *RB_FilePart( char * );
void                RB_Analyse_Defaults_File( void );

void                RB_Slow_Sort( void );
void                RB_Reverse_List( void );
void                RB_Insert_In_List( struct RB_header **,
                                       struct RB_header * );
void                RB_Remove_From_List( struct RB_header **,
                                         struct RB_header * );
struct RB_header   *RB_Alloc_Header( void );
void                RB_Free_Header( struct RB_header * );
int                 RB_WordLen( char * );
char               *RB_StrDup( char * );
char               *RB_CookStr( char * );
void                RB_Say( char *, ... );
void                RB_Warning_Full( char* arg_filename, int arg_line_number, char* arg_format, ... );
void                RB_Warning( char* format, ... );
void                RB_Panic( char *, ... );
int                 RB_Str_Case_Cmp( char *s, char *t );
void                RB_TimeStamp( FILE * f );
char               *RB_Skip_Whitespace( char *buf );

void               *RB_Calloc( size_t count, size_t size );
void               *RB_Malloc( size_t size );
void                RB_Free( void *p );
void                RB_FputcLatin1ToUtf8( FILE *fp, int c );
void                RB_CopyFile( char* sourceFileName, char* destinationFileName );
int                 RB_Match( char* target, char* wildcard_expression );
void                RB_QuickSort( void** array, int left, int right, TCompare f );
void                RB_StripCR( char *line );

char               *ExpandTab( char *line );
#endif /* ROBODOC_UTIL_H */
